@@ -23,16 +23,20 @@ sub graph {
 #warn "$root $root->gi\n";
 
   my $label = $root->gi;
-  my $colour = 'black';
+  my $colour = 'blue';
+  my $shape = "ellipse";
 
   if ($root->is_pcdata) {
     $label = $root->text;
     $label =~ s|^\s+||;
-    $label =~ s|\s$||;
-    $colour = 'darkgreen';
+    $label =~ s|\s+$||;
+    $colour = 'black';
+  } else {
+#      $label = "<$label>";
+      $shape = "diamond";
   }
 
-  $g->add_node({ name => $root, label => $label, color => $colour });
+  $g->add_node({ name => $root, label => $label, color => $colour, shape => $shape});
   foreach my $child ($root->children) {
     $g->add_edge({ from => $root, to => $child });
     graph($g, $child);
@@ -42,4 +46,5 @@ sub graph {
 
 print $g->as_png;
 #print $g->as_text;
+#print $g->_as_debug;
 
